diff --git a/ChangeLog.3 b/ChangeLog.3
index a0a4794b4e..2a9832b67b 100644
--- a/ChangeLog.3
+++ b/ChangeLog.3
@@ -1,3 +1,7 @@
+2018-08-03  Felix E. Klee  <felix.klee@inka.de>
+
+	* lisp/svg.el (svg-path): New function.
+
 2018-07-01  Paul Eggert  <eggert@cs.ucla.edu>
 
 	* etc/HISTORY: Cite Brinkhoff on early history.
diff --git a/doc/lispref/display.texi b/doc/lispref/display.texi
index fef5188197..d45f68d95b 100644
--- a/doc/lispref/display.texi
+++ b/doc/lispref/display.texi
@@ -5541,6 +5541,19 @@ that describe the outer circumference of the polygon.
 @end lisp
 @end defun
 
+@defun svg-path svg commands &rest args
+Add the outline of a shape to @var{svg}. The @var{commands} follow the
+Scalable Vector Graphics standard. This function can be used to create
+arcs.
+
+@lisp
+(svg-path svg '((M 100 300)
+                (A 300 300 0 0 0 300 100)
+                (Z))
+          :stroke-color "blue" :fill-color "yellow")
+@end lisp
+@end defun
+
 @defun svg-text svg text &rest args
 Add a text to @var{svg}.
 
diff --git a/lisp/svg.el b/lisp/svg.el
index 1178905546..e5c4e1383a 100644
--- a/lisp/svg.el
+++ b/lisp/svg.el
@@ -138,6 +138,17 @@ POINTS is a list of x/y pairs."
 			    ", "))
       ,@(svg--arguments svg args)))))
 
+(defun svg-path (svg commands &rest args)
+  "Add the outline of a shape to SVG. The COMMANDS follow the
+Scalable Vector Graphics standard. This function can be used to
+create arcs."
+  (let ((d (mapconcat 'prin1-to-string (apply 'append commands) " ")))
+    (svg--append
+     svg
+     (dom-node 'path
+	       `((d . ,d)
+	         ,@(svg--arguments svg args))))))
+
 (defun svg-embed (svg image image-type datap &rest args)
   "Insert IMAGE into the SVG structure.
 IMAGE should be a file name if DATAP is nil, and a binary string
